Django-pandas is written and maintained by Christopher Clarke and
various contributors:

Development Lead
````````````````

- Christopher Clarke <cclarke@chrisdev.com>

Contributions
``````````````
- `Christopher Clarke <https://github.com/chrisdev>`_
- `Bertrand Bordage <https://github.com/BertrandBordage>`_
- `Guillaume Thomas <https://github.com/gtnx>`_
- `Parbhat Puri  <https://parbhatpuri.com/>`_
- `Fredrik Burman (coachHIPPO) <https://www.coachhippo.com>`_
- `Safe Hammad <http://safehammad.com>`_
- `Jeff Sternber <https://www.linkedin.com/in/jeffsternberg>`_
- `@MiddleFork <https://github.com/MiddleFork>`_
